@@ -2,7 +2,7 @@
 import os
 import sys
 from pathlib import Path
-from typing import Any, NoReturn, Optional, Type, cast
+from typing import Any, List, NoReturn, Optional, Type, cast
 
 import click
 
@@ -64,6 +64,13 @@ from .utils import json_output_option_decorator, retrieve_client
     default=None,
     help="Route ggshield output to file.",
 )
+@click.option(
+    "--banlist-detector",
+    "-b",
+    default=None,
+    help="Exclude results from a detector.",
+    multiple=True,
+)
 @click.pass_context
 def scan(
     ctx: click.Context,
@@ -73,6 +80,7 @@ def scan(
     verbose: bool,
     json_output: bool,
     output: Optional[str],
+    banlist_detector: Optional[List[str]] = None,
 ) -> int:
     """Command to scan various contents."""
     ctx.obj["client"] = retrieve_client(ctx)
@@ -95,6 +103,9 @@ def scan(
     if exit_zero is not None:
         config.exit_zero = exit_zero
 
+    if banlist_detector:
+        config.banlisted_detectors.update(banlist_detector)
+
     output_handler_cls: Type[OutputHandler] = TextHandler
     if json_output:
         output_handler_cls = JSONHandler
@@ -142,9 +153,17 @@ def exit_code(ctx: click.Context, exit_code: int, **kwargs: Any) -> None:
 @click.option(
     "--verbose", "-v", is_flag=True, default=None, help="Verbose display mode."
 )
+@click.option(
+    "--allow-self-signed",
+    is_flag=True,
+    default=None,
+    help="Ignore ssl verification.",
+)
 @click.version_option()
 @click.pass_context
-def cli(ctx: click.Context, config_path: str, verbose: bool) -> None:
+def cli(
+    ctx: click.Context, config_path: str, verbose: bool, allow_self_signed: bool
+) -> None:
     load_dot_env()
     ctx.ensure_object(dict)
     if config_path:
@@ -157,6 +176,9 @@ def cli(ctx: click.Context, config_path: str, verbose: bool) -> None:
     if verbose is not None:
         ctx.obj["config"].verbose = verbose
 
+    if allow_self_signed is not None:
+        ctx.obj["config"].allow_self_signed = allow_self_signed
+
 
 def cli_wrapper() -> NoReturn:
     standalone_mode = not (
