@@ -1,31 +1,24 @@
 from marshmallow import fields
-from marshmallow.schema import Schema
-from pygitguardian.models import MatchSchema
+from pygitguardian.models import BaseSchema, MatchSchema
 
 
-class FlattenedPolicyBreak(Schema):
+class FlattenedPolicyBreak(BaseSchema):
     policy = fields.String(required=True)
     occurrences = fields.List(fields.Nested(MatchSchema), required=True)
     break_type = fields.String(data_key="type", required=True)
     ignore_sha = fields.String(required=True)
     total_occurrences = fields.Integer(required=True)
 
-    class Meta:
-        ordered = True
 
-
-class JSONResultSchema(Schema):
+class JSONResultSchema(BaseSchema):
     mode = fields.String(required=True)
     filename = fields.String(required=True)
     incidents = fields.List(fields.Nested(FlattenedPolicyBreak), required=True)
     total_incidents = fields.Integer(required=True)
     total_occurrences = fields.Integer(required=True)
 
-    class Meta:
-        ordered = True
 
-
-class JSONScanCollectionSchema(Schema):
+class JSONScanCollectionSchema(BaseSchema):
     id = fields.String()
     type = fields.String()
     results = fields.List(
@@ -35,6 +28,4 @@ class JSONScanCollectionSchema(Schema):
     extra_info = fields.Dict(keys=fields.Str(), values=fields.Str())
     total_incidents = fields.Integer(required=True)
     total_occurrences = fields.Integer(required=True)
-
-    class Meta:
-        ordered = True
+    secrets_engine_version = fields.String(required=False)
