@@ -7,5 +7,6 @@ from snapshottest import Snapshot
 
 snapshots = Snapshot()
 
-snapshots['test_message_no_secret 1'] = '''\x1b[37m\x1b[22m\x1b[22mNo secrets have been found
+snapshots['test_message_no_secret 1'] = '''\x1b[37m\x1b[22m\x1b[22m
+No secrets have been found
 \x1b[0m'''
